@@ -16,10 +16,10 @@ from ecoindex_cli.cli.arguments_handler import (
     get_window_sizes_from_args,
 )
 from ecoindex_cli.cli.helper import run_page_analysis
-from ecoindex_cli.enums import ExportFormat
+from ecoindex_cli.enums import ExportFormat, Language
 from ecoindex_cli.files import write_results_to_file, write_urls_to_file
 from ecoindex_cli.logger import Logger
-from ecoindex_cli.report.report import generate_report
+from ecoindex_cli.report.report import Report
 from pydantic.error_wrappers import ValidationError
 from typer import Argument, Option, colors, confirm, progressbar, secho
 from typer.main import Typer
@@ -63,6 +63,11 @@ def analyze(
         help="You can export the results in json or csv. Default is csv. If you generate an HTML report, this option is ignored",
         case_sensitive=False,
     ),
+    html_report_language: Optional[Language] = Option(
+        default=Language.en.value,
+        help="You can define the language of the html report. Default is english",
+        case_sensitive=False,
+    ),
 ):
     """
     Make an ecoindex analysis of given webpages or website. You
@@ -138,6 +143,8 @@ def analyze(
     with progressbar(
         length=len(urls) * len(window_sizes),
         label="Processing",
+        show_percent=True,
+        show_pos=True,
     ) as progress:
         error_found = False
         with ThreadPoolExecutor(max_workers=max_workers) as executor:
@@ -154,7 +161,7 @@ def analyze(
                     results.append(future.result())
                 except Exception as e:
                     error_found = True
-                    log.error(" -- " + url + " -- " + e.msg)
+                    log.error(f" -- {url} -- {e.msg if hasattr(e, 'msg') else e}")
 
                 progress.update(1)
 
@@ -181,12 +188,14 @@ def analyze(
     )
     secho(f"🙌️ File {output_filename} written !", fg=colors.GREEN)
     if html_report:
-        generate_report(
+        Report(
             results_file=output_filename,
             output_path=output_folder,
-            file_prefix=file_prefix,
+            domain=file_prefix,
             date=time_now,
-        )
+            language=html_report_language,
+        ).create_report()
+
         secho(
             f"🦄️ Amazing! A report has been generated to {output_folder}/index.html",
             fg=colors.GREEN,
@@ -207,6 +216,11 @@ def report(
         default=None,
         help="By default, we generate the report in the same folder of the results file, but you can provide another folder",
     ),
+    html_report_language: Optional[Language] = Option(
+        default=Language.en.value,
+        help="You can define the language of the html report. Default is english",
+        case_sensitive=False,
+    ),
 ):
     """
     If you already performed an ecoindex analysis and have your results,
@@ -214,12 +228,14 @@ def report(
     """
     output_folder = output_folder if output_folder else dirname(results_file)
 
-    generate_report(
+    Report(
         results_file=results_file,
         output_path=output_folder,
-        file_prefix=domain,
+        domain=domain,
         date=datetime.now(),
-    )
+        language=html_report_language,
+    ).create_report()
+
     secho(
         f"🦄️ Amazing! A report has been generated to {output_folder}/index.html",
         fg=colors.GREEN,
